@@ -38,7 +38,11 @@ void RegisterGtkObject(HV * hv_object, GtkObject * gtk_object)
 	
 	/*printf("Recording %d as '%s'\n", hv_object, buffer);*/
 
+
+
 	hv_store(ObjectCache, buffer, strlen(buffer), newRV((SV*)hv_object), 0);
+
+	/*hv_store(ObjectCache, buffer, strlen(buffer), newSViv((int)hv_object), 0);*/
 }
 
 HV * RetrieveGtkObject(GtkObject * gtk_object)
@@ -51,6 +55,8 @@ HV * RetrieveGtkObject(GtkObject * gtk_object)
 		ObjectCache = newHV();
 
 	s = hv_fetch(ObjectCache, buffer, strlen(buffer), 0);
+	
+	/*printf("Looking for PO to match GO %p\n", gtk_object);*/
 
 	/*printf("Retrieving '%s' as %d\n", buffer, (s ? (int)*s : 0));*/
 
@@ -60,23 +66,52 @@ HV * RetrieveGtkObject(GtkObject * gtk_object)
 		return 0;
 }
 
+void GCGtkObjects(void) {
+  if (ObjectCache)
+    {
+      int count = 0;
+      int dead = 0;
+      HE *iter;
+      hv_iterinit (ObjectCache);
+      while ((iter = hv_iternext (ObjectCache)))
+        {
+          HV *hv_obj = (HV *)SvRV(HeVAL(iter));
+          GtkObject *obj = (GtkObject *)SvIV (*hv_fetch (hv_obj, "_gtk", 4, 0));
+          if ((obj->ref_count == 1) && (SvREFCNT(hv_obj) == 1)) {
+            dead++;
+            SvREFCNT_dec(hv_obj);
+          }
+          count++;
+        }
+      /*      fprintf(stderr, "Count: %d; Dead %d\n", count, dead); */
+    }
+}
+
 extern AV * gtk_typecasts;
 
 static void DisconnectGtkObject(GtkObject * object, gpointer data)
 {
 	HV * h = (HV*)data;
+	/*printf("DisconnectGtkObject called on GO %p, PO %p\n", object, h);*/
+	
 	/*printf("Disconnecting Gtk object %d/%d\n", data, object);*/
 	UnregisterGtkObject(h, object);
+	/*if (GTK_OBJECT_FLOATING(object)) {
+		printf("GO %p is floating, sinking.\n", object);
+		gtk_object_sink(object);
+	}*/
 	/*printf("Destroying hv %d, with object %d\n", h, object);*/
 	/*hv_delete(h, "_gtk", 4, G_DISCARD); Busted, sigh */
 }
 
+
 SV * newSVGtkObjectRef(GtkObject * object, char * classname)
 {
 	HV * previous = RetrieveGtkObject(object);
 	SV * result;
 	if (previous) {
 		result = newRV((SV*)previous);
+		/*printf("Returning previous PO %p, referencing GO %p\n", previous, object);*/
 		/*printf("Returning previous ref %d as %d (%d)\n", object, previous, result);*/
 		/*SvREFCNT_dec(SvRV(result));*/
 	} else {
@@ -96,10 +131,11 @@ SV * newSVGtkObjectRef(GtkObject * object, char * classname)
 		RegisterGtkObject(h, object);
 		/*printf("Setting hv %d up for destruction on object %d\n", h, object);*/
 		gtk_signal_connect(object, "destroy", (GtkSignalFunc)DisconnectGtkObject, (gpointer)h);
+		/*gtk_object_weakref(object, (GtkDestroyNotify)DisconnectGtkObject, (gpointer)h);*/
 		sv_bless(result, gv_stashpv(classname, FALSE));
 		SvREFCNT_dec(h);
 		/*gtk_object_ref(object);*/
-		/*printf("Returning new ref %d as %d\n", object, result);*/
+		/*printf("Creating new PO %p referencing GO %p\n", h, object);*/
 	}
 	return result;
 }
@@ -120,6 +156,20 @@ GtkObject * SvGtkObjectRef(SV * o, char * name)
 
 void disconnect_GtkObjectRef(SV * o)
 {
+#if 0
+	HV * q;
+	SV ** r;
+	GtkObject * object;
+	printf("DESTROY PO %p\n", o);
+	/*printf("Trying to delete GtkObject %d\n", o);*/
+	if (!o || !SvOK(o) || !(q=(HV*)SvRV(o)) || (SvTYPE(q) != SVt_PVHV))
+		return;
+	r = hv_fetch(q, "_gtk", 4, 0);
+	if (!r || !SvIV(*r))
+		return;
+	object = (GtkObject*)SvIV(*r);
+	printf("(And thus GO %p)\n", object);
+#endif
 #if 0
 	HV * q;
 	SV ** r;
